[![Build Status](https://travis-ci.org/jrmsdev/pysadm.svg?branch=master)](https://travis-ci.org/jrmsdev/pysadm) [![codecov](https://codecov.io/gh/jrmsdev/pysadm/branch/master/graph/badge.svg)](https://codecov.io/gh/jrmsdev/pysadm) [![Current Version](https://img.shields.io/pypi/v/sadm.svg)](https://pypi.org/project/sadm/)

# sadm

sysadmin/devops/deployment tools

## install

	$ pip3 install sadm
